==> haskell-io-streams-haproxy-1.0.0.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-D6RhKXS4zJI6rVYjArxDKQ
key: io-streams-haproxy-1.0.0.2-D6RhKXS4zJI6rVYjArxDKQ
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 0f7e35db0033186c09d39d0424c906c8
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-D6RhKXS4zJI6rVYjArxDKQ
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    bytestring-0.10.8.2 io-streams-1.5.0.1-Axt1wq0YNM3Linfis9iVtB
    network-2.7.0.2-6FfBvmD6NTeAPSa47HXiSR transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             io-streams-1.5.0.1-Axt1wq0YNM3Linfis9iVtB=042f420d0d36aae264f073533a6491ef
             network-2.7.0.2-6FfBvmD6NTeAPSa47HXiSR=614b1a60f3013422c23df99507b7d70f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.0.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-CGpJlFDpUiR9N8Xs3mvfjD
key: io-streams-haproxy-1.0.0.2-CGpJlFDpUiR9N8Xs3mvfjD
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 129f98fcc317c4decae7d90b41c9d298
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-CGpJlFDpUiR9N8Xs3mvfjD
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ
    bytestring-0.10.8.2 io-streams-1.5.0.1-1DE7scOOFNtK1PAKVdK58v
    network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ=5fc61cc528c94bde8145f6cbd8ed3b00
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             io-streams-1.5.0.1-1DE7scOOFNtK1PAKVdK58v=4667d18502c9be822da79bad63741975
             network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv=9f4c0094002519cc1dc579d0a3bd3879
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
